<?php
// No direct file access
if ( ! defined( 'ABSPATH' ) ) exit; 

$beebogo_settings = get_option('beebogo_settings');
$enabled = $beebogo_settings['enabled'];

if ( $enabled == 'off' ) {
	return;
}



// check bogo by product id
function beebogo_check_product_bogo($product_id) {
	$beebogo_settings 	= get_option('beebogo_settings');
	$select_category 	= $beebogo_settings['rules']['category'];
	$select_products 	= $beebogo_settings['rules']['products'];

	if ( empty($select_products) ) {

		$products = get_posts(array(
		    'post_type' => 'product',
		    'posts_per_page' => -1,
		    'tax_query' => array(
		        array(
		            'taxonomy' => 'product_cat',
		            'field' => 'term_id',
		            'terms' => $select_category,
		        ),
		    ),
		));

		$select_products = wp_list_pluck($products, 'ID');
	}

	if ( in_array( $product_id, $select_products ) ) {
		return true;
	}
	else {
		return false;
	}
}

// Add BOGO badge to product loop
function beebogo_add_badge_to_product_loop() {
    global $product;
    $product_id = $product->id;

    // Check if the product is on BOGO
    if ( beebogo_check_product_bogo($product_id) ) {
        echo '<span class="bee-bogo-badge"><span class="buy-one">'. esc_html__('Buy One', 'bee_bogo').'</span><span class="get-one">'. esc_html__('Get One', 'bee_bogo').'</span></span>';
    }
}
add_action('woocommerce_before_shop_loop_item_title', 'beebogo_add_badge_to_product_loop', 10);

// Add BOGO badge to single product
function beebogo_add_badge_to_single_product() {
    global $product;

    $product_id = $product->id;

    // Check if the product is on BOGO
    if ( beebogo_check_product_bogo($product_id) ) {
        echo '<div class="bee-bogo-badge-single"><span class="bee-bogo-badge"><span class="buy-one">'. esc_html__('Buy One', 'bee_bogo').'</span><span class="get-one">'. esc_html__('Get One', 'bee_bogo').'</span></span></div>';
    }
}
add_action('woocommerce_after_add_to_cart_form', 'beebogo_add_badge_to_single_product', 10);

// auto add to cart 
function beebogo_auto_add_quantity( $quantity, $product_id ) {

	if ( beebogo_check_product_bogo($product_id) ) {
		$quantity *= 2;
	}

    return $quantity;
}
add_filter('woocommerce_add_to_cart_quantity', 'beebogo_auto_add_quantity', 10, 2 );

// add discount to cart 
function beebogo_add_fee_based_on_product() {
	$bogoitems = array();

    foreach ( WC()->cart->get_cart() as $cart_item ) {

    	if ( beebogo_check_product_bogo( $cart_item['product_id'] ) ) {
    		$product_id = $cart_item['product_id'];

    		if ( $cart_item['quantity'] >= 2 ) {
    			$free_items = intval( (int)$cart_item['quantity'] / 2 );

    			if ($cart_item['variation_id'] > 0) {
    				$variation_id 	= $cart_item['variation_id'];
            		$variation 		= wc_get_product($variation_id);
            		$item_price 	= $variation->get_price();
            		$free_amount 	= $item_price * $free_items;
    			}
    			else {
    				$product 		= wc_get_product($product_id);
    				$item_price 	= $product->get_price();
    				$free_amount 	= $item_price * $free_items;
    			}
    		}
    		else {
    			$free_amount = 0;
    		}

    		if ( !empty( $bogoitems[ $cart_item['product_id'] ] ) ) {
    			$bogoitems[$cart_item['product_id']] += $free_amount;
    		}
    		else {
    			$bogoitems[$cart_item['product_id']] = $free_amount;
    		}
    	}
    }

    if ( !empty( $bogoitems ) ) {

        $fee_label 	= __('Buy One Get One', 'bee_bogo');
        $fee_amount = array_sum($bogoitems);

        // Add the fee to the cart
        WC()->cart->add_fee($fee_label, - $fee_amount);
    }
}
add_action('woocommerce_cart_calculate_fees', 'beebogo_add_fee_based_on_product');