<?php
// No direct file access
if ( ! defined( 'ABSPATH' ) ) exit; 

/**
 * loader class for BeeBOGO
 */
class BeeBOGOF_Loader
{
	
	function __construct()
	{
		if ( is_admin() ) {
			$this->beebogo_include_admin_files();
		}
		else {
			$this->beebogo_include_public_files();
		}
	}

	/**
	 * include required files for admin and hook required for wordpress to triger
	 */
	public function beebogo_include_admin_files() {

		add_action( 'admin_notices', array( $this, 'beebogo_check_required_plugins' ) );
        add_filter( 'plugin_action_links_' . BeeBOGOF_BASE, array( $this, 'beebogo_add_plugin_settins_links' ) );
        add_action( 'init', array( $this, 'beebogo_check_for_plugin_update' ) );
        add_action( 'admin_notices', array( $this, 'beebogo_display_update_notice' ) );
        

       	include_once BeeBOGOF_PATH . 'admin/bee-bogo-settings.php';
       	include_once BeeBOGOF_PATH . 'admin/beeplugins-addons.php';
       	add_action( 'admin_enqueue_scripts', array( $this, 'beebogo_enqueue_admin_scripts' ) );
    }

    /**
	 * include required files for public
	 */
	public function beebogo_include_public_files() {

       	include_once BeeBOGOF_PATH . 'includes/bee-bogo-functions.php';
       	add_action( 'wp_enqueue_scripts', array( $this, 'beebogo_enqueue_public_scripts' ) );
    }

    /**
	 * check woocommerce activation before installation 
	 */
    public function beebogo_check_required_plugins( $plugin ) {

    	if ( ! is_plugin_active('woocommerce/woocommerce.php') ) {
            ?>
            <div id="message" class="error">
                <p>Bee BOGO for WooCommerce required <a href="http://www.woothemes.com/woocommerce/" target="_blank">WooCommerce</a> to be activated in order to work. Please install and activate <a href="<?php echo admin_url('/plugin-install.php?tab=search&amp;type=term&amp;s=WooCommerce'); ?>" target="">WooCommerce</a> first.</p>
            </div>
            <?php
            deactivate_plugins(BeeBOGOF_BASE);
        }
    }

    /**
	 * add settings link to beeBOGO 
	 */
    public function beebogo_add_plugin_settins_links( $links ) {

    	if ( is_plugin_active('woocommerce/woocommerce.php') ) {
            array_unshift( $links, '<a href="' . admin_url('admin.php?page=bee-bogo-settings') . '">Settings</a>');
        }
        return $links;
    }

    /**
	 * check for updates
	 */
    public function beebogo_check_for_plugin_update() {
    	$current_version = BeeBOGOF_Version;
    	$bee_update_server_url = 'https://www.beeplugin.com';
    	$response = wp_remote_get( $bee_update_server_url . '/update-check.php?plugin=bee-bogo-for-woocommerce-pro&version=' . $current_version);

    	if (!is_wp_error($response)) {
	        $body = wp_remote_retrieve_body($response);
	        $data = json_decode($body);

	        if ($data && version_compare($data->version, $current_version, '>')) {
	            set_transient('beebogo_update_available', $data);
	        }
	    }
    }

    /**
	 * show update notice
	 */
    public function beebogo_display_update_notice() {

    	$update = get_transient('beebogo_update_available');

	    if ($update) {
	        ?>
	        <div class="notice notice-info is-dismissible">
	            <p>Update available: <?php echo esc_html($update->version); ?>. <a href="<?php echo esc_url(admin_url('update.php?action=upgrade-plugin&plugin=bee-bogo-for-woocommerce')); ?>">Update now</a>.</p>
	        </div>
	        <?php
	        delete_transient('beebogo_update_available');
	    }
    }

    /**
	 * add all admin css and js
	 */
    public function beebogo_enqueue_admin_scripts() {

    	if ( isset($_GET['page']) && ( $_GET['page'] === 'bee-bogo-settings' ||  $_GET['page'] === 'bee-plugins' ) ) {
	        wp_enqueue_style( 'bee-bogo-admin', BeeBOGOF_URL . '/assets/css/bogo-admin.css');
	        wp_enqueue_script('select2', BeeBOGOF_URL . '/assets/js/select2.min.js', array('jquery'), '', true);
			wp_enqueue_style('select2', BeeBOGOF_URL . '/assets/css/select2.min.css');
			wp_register_script( 'bee-bogo-admin', BeeBOGOF_URL . '/assets/js/bogo-admin.js', array('jquery', 'select2'), time(), true );
			wp_enqueue_script('bee-bogo-admin');

			$loc_data = array(
			    'ajax_url' => admin_url('admin-ajax.php'),
			    'nonce'    => wp_create_nonce('beebogo'),
			);

			wp_localize_script('bee-bogo-admin', 'beebogo', $loc_data);
		
	    }
	    if ( isset($_GET['page']) && $_GET['page'] === 'bee-plugins-addons' ) {
	    	wp_enqueue_style( 'bee-addons', BeeBOGOF_URL . '/assets/css/addons.css');
	    }
    }
    
    /**
	 * add all public css and js
	 */
    public function beebogo_enqueue_public_scripts() {

		wp_enqueue_style( 'bee-bogo', BeeBOGOF_URL . '/assets/css/bogo-style.css');

    }
}